summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--gnu/packages/cross-base.scm4
-rw-r--r--gnu/packages/firmware.scm8
2 files changed, 6 insertions, 6 deletions
diff --git a/gnu/packages/firmware.scm b/gnu/packages/firmware.scm
index 7923f5c908..1526a125f3 100644
--- a/gnu/packages/firmware.scm
+++ b/gnu/packages/firmware.scm
@@ -121,7 +121,7 @@
              ;; 'configure' is a simple script that runs 'cmake' with
              ;; the right flags.
              (substitute* "configure"
-               (("^TARGET.*$") "TARGET=xtensa-elf\n")
+               (("^TARGET.*$") "TARGET=xtensa-ath9k-elf\n")
                (("^TOOLCHAIN=.*$")
                 (string-append "TOOLCHAIN="
                                (assoc-ref (or native-inputs inputs) "cross-gcc")
@@ -140,12 +140,12 @@
     ;; The firmware is cross-compiled using a "bare bones" compiler (no libc.)
     ;; Use our own tool chain for that.
     (native-inputs `(("cross-gcc" ,(cross-gcc
-                                    "xtensa-elf"
+                                    "xtensa-ath9k-elf"
                                     #:xbinutils (cross-binutils
-                                                 "xtensa-elf"
+                                                 "xtensa-ath9k-elf"
                                                  #:binutils binutils-2.33)))
                      ("cross-binutils" ,(cross-binutils
-                                         "xtensa-elf"
+                                         "xtensa-ath9k-elf"
                                          #:binutils binutils-2.33))
                      ("cmake" ,cmake-minimal)
                      ("perl" ,perl)))
diff --git a/gnu/packages/cross-base.scm b/gnu/packages/cross-base.scm
index 36307698a8..ab8c757acc 100644
--- a/gnu/packages/cross-base.scm
+++ b/gnu/packages/cross-base.scm
@@ -118,8 +118,8 @@
                         ;; target libs, not native libs, so this is safe.
                         `(cons "--with-sysroot=/" ,flags)))))))
 
-    ;; For Xtensa, apply Qualcomm's patch.
-    (cross (cond ((string-prefix? "xtensa-" target)
+    ;; For xtensa-ath9k-elf, apply Qualcomm's patch.
+    (cross (cond ((string=? target "xtensa-ath9k-elf")
                   (package-with-patches binutils
                                         (search-patches
                                          "ath9k-htc-firmware-binutils.patch")))